export const labelRequired = 'Required';
export const labelLoginSucceeded = 'Login succeeded';
export const labelAlias = 'Alias';
export const labelPassword = 'Password';
export const labelLogin = 'Login';
export const labelCentreonLogo = 'Centreon Logo';
export const labelConnect = 'Connect';
export const labelDisplayThePassword = 'Display the password';
export const labelHideThePassword = 'Hide the password';
export const labelOr = 'or';
export const labelLoginWith = 'Login with';
export const labelPasswordHasExpired = 'Password has expired';
export const labelCentreonWallpaper = 'Centreon wallpaper';
export const labelPoweredByCentreon = 'Powered by Centreon';
export const labelAnErrorOccurredDuringAuthentication =
  'An error occurred during authentication';
